package My::Test;
use strict;
use warnings;

our $VERSION = "0.0.1";
#use 5.008;

=head1 NAME

My::Test - write description here

=head1 SYNOPSIS

write synopsis here

=head1 DESCRIPTION

write description here
=cut


1;
__END__

=head1 AUTHOR

Takuya Tsuchida E<lt>takuya.tsuchida@gmail.com<gt>

=head1 SEE ALSO

write here if related module exists

=head1 REPOSITORY

write source code repository

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
